# Test data for indexed particle reader

This directory contains a small, spatially sorted particle
lightcone. It was generated by random sampling the BH particle
lightcone output for the L1_m9 FLAMINGO run and then using the
particle_sorter code to regenerate the spatial indexing.
